/* Copyright(c) 1994  Danny Sadinoff
  See section COPYING for conditions for redistribution
*/
#ifndef __SEDRA__
#define __SEDRA__

char *sedra( long int absDate );
void reset_sedra( int );

#endif
